==> matter-tools-0.12.0.tgz: package/README.md <==
# matter-tools

> Tools for creating, testing and debugging matter.js worlds

## Demo

See the [demo](http://liabru.github.io/matter-tools/).

## Tools

- `MatterTools.Demo` for running and testing examples
- `MatterTools.Gui` for experimenting with engine properties
- `MatterTools.Inspector` for inspecting composites, bodies and constraints
- `MatterTools.Serializer` for saving and loading state (experimental)

Each tool can be used independently as needed.

## Install

You can install using [npm](https://www.npmjs.com/):

    npm install matter-tools

### Bundles

Alternatively the following split bundle builds are provided for convenience:

- [build/matter-tools.demo.js](https://github.com/liabru/matter-tools/blob/master/build)
- [build/matter-tools.gui.js](https://github.com/liabru/matter-tools/blob/master/build) (bundles [dat.gui](https://github.com/dataarts/dat.gui))
- [build/matter-tools.inspector.js](https://github.com/liabru/matter-tools/blob/master/build) (bundles [keymaster](https://github.com/madrobby/keymaster), [jquery](https://github.com/jquery/jquery), [jstree](https://github.com/vakata/jstree))
- [build/matter-tools.serializer.js](https://github.com/liabru/matter-tools/blob/master/build) (bundles [resurrect-js](https://github.com/skeeto/resurrect-js))

See the section below regarding license.

## Usage

See the [demo source](https://github.com/liabru/matter-tools/tree/master/docs) 
for a usage example.

## Documentation

See the [API docs](https://github.com/liabru/matter-tools/blob/master/API.md) for documentation.

## License

`matter-tools` is released under MIT see [LICENSE](https://github.com/liabru/matter-tools/blob/master/LICENSE)

Dependencies are used under their own individual respective licenses, consult their documentation for information.

==> matter-tools-0.14.0.tgz: package/README.md <==
# matter-tools

> Tools for creating, testing and debugging matter.js worlds

## Demo

See the [demo](http://liabru.github.io/matter-tools/).

## Tools

- `MatterTools.Demo` for running and testing examples
- `MatterTools.Gui` for experimenting with engine properties
- `MatterTools.Inspector` for inspecting composites, bodies and constraints
- `MatterTools.Serializer` for saving and loading state (experimental)

Each tool can be used independently as needed.

## Install

You can install using [npm](https://www.npmjs.com/):

    npm install matter-tools

### Bundles

Alternatively the following complete bundle is provided for convenience

- [build/matter-tools.js](https://github.com/liabru/matter-tools/blob/master/build)

Individual smaller bundles for each tool are also available
- [build/matter-tools.demo.js](https://github.com/liabru/matter-tools/blob/master/build)
- [build/matter-tools.gui.js](https://github.com/liabru/matter-tools/blob/master/build) (bundles [dat.gui](https://github.com/dataarts/dat.gui))
- [build/matter-tools.inspector.js](https://github.com/liabru/matter-tools/blob/master/build) (bundles [keymaster](https://github.com/madrobby/keymaster), [jquery](https://github.com/jquery/jquery), [jstree](https://github.com/vakata/jstree))
- [build/matter-tools.serializer.js](https://github.com/liabru/matter-tools/blob/master/build) (bundles [resurrect-js](https://github.com/skeeto/resurrect-js))

See the section below regarding license.

## Usage

See the [demo source](https://github.com/liabru/matter-tools/tree/master/docs) 
for a usage example.

## Documentation

See the [API docs](https://github.com/liabru/matter-tools/blob/master/API.md) for documentation.

## License

`matter-tools` is released under MIT see [LICENSE](https://github.com/liabru/matter-tools/blob/master/LICENSE)

Dependencies are used under their own individual respective licenses, consult their documentation for information.
